@@ -1,5 +1,5 @@
 import json
-import mock as mock
+from mock import MagicMock, patch, mock_open
 import pytest
 import respx
 from httpx import Response
@@ -8,7 +8,23 @@ from .expertAdvisor_client import ExpertAdvisorClient
 
 PROVISIONING_API_URL = 'https://mt-provisioning-api-v1.agiliumtrade.agiliumtrade.ai'
 httpClient = HttpClient()
-expert_advisor_client = ExpertAdvisorClient(httpClient, 'header.payload.sign')
+token = 'header.payload.sign'
+account_token = 'token'
+domain_client: MagicMock = None
+expert_advisor_client: ExpertAdvisorClient = None
+
+
+@pytest.fixture(autouse=True)
+async def run_around_tests():
+    global http_client
+    http_client = HttpClient()
+    global domain_client
+    domain_client = MagicMock()
+    domain_client.token = token
+    domain_client.domain = 'agiliumtrade.agiliumtrade.ai'
+    global expert_advisor_client
+    expert_advisor_client = ExpertAdvisorClient(http_client, domain_client)
+    yield
 
 
 class TestExpertAdvisorClient:
@@ -33,7 +49,8 @@ class TestExpertAdvisorClient:
     @pytest.mark.asyncio
     async def test_not_retrieve_advisors_with_account_token(self):
         """Should not retrieve expert advisors from API with account token."""
-        expert_advisor_client = ExpertAdvisorClient(httpClient, 'token')
+        domain_client.token = account_token
+        expert_advisor_client = ExpertAdvisorClient(http_client, domain_client)
         try:
             await expert_advisor_client.get_expert_advisors('id')
         except Exception as err:
@@ -62,9 +79,11 @@ class TestExpertAdvisorClient:
     @pytest.mark.asyncio
     async def test_not_retrieve_advisor_with_account_token(self):
         """Should not retrieve expert advisor from API with account token."""
-        expert_advisor_client = ExpertAdvisorClient(httpClient, 'token')
+        domain_client.token = account_token
+        expert_advisor_client = ExpertAdvisorClient(http_client, domain_client)
         try:
             await expert_advisor_client.get_expert_advisor('id', 'my-ea')
+            pytest.fail()
         except Exception as err:
             assert err.__str__() == 'You can not invoke get_expert_advisor method, because you ' + \
                    'have connected with account access token. Please use API access token from ' + \
@@ -84,9 +103,11 @@ class TestExpertAdvisorClient:
     @pytest.mark.asyncio
     async def test_not_delete_advisor_with_account_token(self):
         """Should not delete expert advisor from API with account token."""
-        expert_advisor_client = ExpertAdvisorClient(httpClient, 'token')
+        domain_client.token = account_token
+        expert_advisor_client = ExpertAdvisorClient(http_client, domain_client)
         try:
             await expert_advisor_client.delete_expert_advisor('id', 'my-ea')
+            pytest.fail()
         except Exception as err:
             assert err.__str__() == 'You can not invoke delete_expert_advisor method, because you ' + \
                     'have connected with account access token. Please use API access token from ' + \
@@ -117,9 +138,11 @@ class TestExpertAdvisorClient:
             'period': '15m',
             'symbol': 'EURUSD'
         }
-        expert_advisor_client = ExpertAdvisorClient(httpClient, 'token')
+        domain_client.token = account_token
+        expert_advisor_client = ExpertAdvisorClient(http_client, domain_client)
         try:
             await expert_advisor_client.update_expert_advisor('id', 'my-ea', advisor)
+            pytest.fail()
         except Exception as err:
             assert err.__str__() == 'You can not invoke update_expert_advisor method, because you ' + \
                    'have connected with account access token. Please use API access token from ' + \
@@ -131,7 +154,7 @@ class TestExpertAdvisorClient:
         """Should upload file to an expert advisor via API."""
         rsps = respx.put(f'{PROVISIONING_API_URL}/users/current/accounts/id/expert-advisors/my-ea/file') \
             .mock(return_value=Response(204))
-        with mock.patch('__main__.open', new=mock.mock_open(read_data='test')) as file:
+        with patch('__main__.open', new=mock_open(read_data='test')) as file:
             file.return_value = json.dumps('test').encode()
             await expert_advisor_client.upload_expert_advisor_file('id', 'my-ea', file())
             assert rsps.calls[0].request.url == \
@@ -141,10 +164,12 @@ class TestExpertAdvisorClient:
     @pytest.mark.asyncio
     async def test_not_upload_file_with_account_token(self):
         """Should not upload file to an expert advisor via API with account token."""
-        with mock.patch('__main__.open', new=mock.mock_open(read_data='test')) as file:
-            expert_advisor_client = ExpertAdvisorClient(httpClient, 'token')
+        with patch('__main__.open', new=mock_open(read_data='test')) as file:
+            domain_client.token = account_token
+            expert_advisor_client = ExpertAdvisorClient(http_client, domain_client)
             try:
                 await expert_advisor_client.upload_expert_advisor_file('id', 'my-ea', file())
+                pytest.fail()
             except Exception as err:
                 assert err.__str__() == 'You can not invoke upload_expert_advisor_file method, because you ' + \
                        'have connected with account access token. Please use API access token from ' + \
